@@ -3,8 +3,6 @@ package org.codehaus.mojo.buildhelper.versioning;
 public interface Versioning
 {
 
-    boolean isSnapshot();
-    
     int getMajor();
 
     int getMinor();
@@ -13,7 +11,7 @@ public interface Versioning
 
     String getAsOSGiVersion();
 
-    int getBuildNumber();
+    long getBuildNumber();
 
     String getQualifier();
 
